.. _spider_indiehackers.com:

indiehackers.com
----------------
Newest interviews on `Indie Hackers <https://indiehackers.com>`_.

Configuration
~~~~~~~~~~~~~
Add ``indiehackers.com`` to the list of spiders:

.. code-block:: ini

   # List of spiders to run by default, one per line.
   spiders =
     indiehackers.com

